# tail

print the last 10 lines of a file to stdout

    tail file.txt


print the last 20 lines of file1.txt and file2.txt

    tail -n 20 file1.txt file2.txt


print the last 10 bytes of a file

    tail -c 10 file.txt


print a file starting at line 10

    tail +10 file.txt


print and monitor the last lines of a file as it grows

    tail -f file.txt


reverse the lines of a file

    tail -r file.txt



# Basic Usage

Print the last lines of a file:

    tail <file>


